==> dmc-sdk-5.2.2.0-sources.jar: com/digiwin/dmc/sdk/service/discard/IDocumentStorageServiceDiscard.java <==
package com.digiwin.dmc.sdk.service.discard;

import com.digiwin.dap.middleware.dmc.common.context.TenantId;
import com.digiwin.dmc.sdk.entity.BatchOperationIds;
import com.digiwin.dmc.sdk.entity.ContentsResult;
import com.digiwin.dmc.sdk.entity.DirInfo;
import com.digiwin.dmc.sdk.entity.FileInfo;
import com.digiwin.dmc.sdk.entity.Query.FileInfoQuery;
import com.digiwin.dmc.sdk.entity.Query.FullTextCondition;
import com.digiwin.dmc.sdk.entity.Query.QueryResult;
import com.digiwin.dmc.sdk.service.download.IGeneralDocumentDownloader;
import com.digiwin.dmc.sdk.service.download.ISegmentDocumentDownloader;
import com.digiwin.dmc.sdk.service.upload.IGeneralDocumentUploader;
import com.digiwin.dmc.sdk.service.upload.ISegmentDocumentUploader;

/**
 * <ol>
 *      <li>以下API是旧版本Bucket租户拼接方案，此方案已经废弃，请不要使用.</li>
 *      <li>文件上传下载添加租户ID，可以通过如下方案：</li>
 *      <ol>
 *          <li>旧版API(即：com.digiwin.dmc)：通过方法参数{@link FileInfo#setTenantId(String)}或者通过方法参数{@link TenantId#of(String)}</li>
 *          <li>新版API(即：com.digiwin.dap.middleware)：{@link  com.digiwin.dap.middleware.dmc.DMC#setTenantId(String)}</li>
 *      </ol>
 *      <li>新版本使用范例：<a href="http://10.40.42.38/middleware/dapware-project/tree/2.3.x/dapware-samples/dapware-java/src/main/java/com/digiwin/dap/sdk/dmc">参考 </a></li>
 * <ol>
 *
 * @author fobgo
 * @date 2022/6/8 13:31
 */
@Deprecated
public interface IDocumentStorageServiceDiscard {

    @Deprecated
    IGeneralDocumentUploader uploadDocumentByTenant(String discardTenantId, String bucketName, String localPath, FileInfo fileInfo);

    @Deprecated
    IGeneralDocumentUploader uploadDocumentByTenant(String discardTenantId, String bucketName, byte[] bytes, FileInfo fileInfo);

    @Deprecated
    IGeneralDocumentUploader uploadDocumentByTenant(String discardTenantId, String bucketName, String localPath, FileInfo fileInfo, String driveToken);

    @Deprecated
    IGeneralDocumentUploader uploadDocumentByTenant(String discardTenantId, String bucketName, byte[] bytes, FileInfo fileInfo, String driveToken);

    @Deprecated
    ISegmentDocumentUploader getUploaderByTenant(String discardTenantId, String localPath, FileInfo fileInfo);

    @Deprecated
    ISegmentDocumentUploader getUploaderByTenant(String discardTenantId, byte[] bytes, FileInfo fileInfo);

    @Deprecated
    ISegmentDocumentUploader getUploaderByTenant(String discardTenantId, String bucketName, String localPath, FileInfo fileInfo);

    @Deprecated
    ISegmentDocumentUploader getUploaderByTenant(String discardTenantId, String bucketName, byte[] bytes, FileInfo fileInfo);

    @Deprecated
    ISegmentDocumentUploader getUploaderByTenant(String discardTenantId, String bucketName, String localPath, FileInfo fileInfo, String driveToken);

    @Deprecated
    ISegmentDocumentUploader getUploaderByTenant(String discardTenantId, String bucketName, byte[] bytes, FileInfo fileInfo, String driveToken);

    @Deprecated
    IGeneralDocumentDownloader downloadDocumentByTenant(String discardTenantId, String fileId, String saveToPath);

    @Deprecated
    IGeneralDocumentDownloader downloadDocumentByTenant(String discardTenantId, String bucketName, String fileId, String saveToPath);

    @Deprecated
    IGeneralDocumentDownloader downloadDocumentByTenant(String discardTenantId, String bucketName, String fileId, String saveToPath, String driveToken);

    @Deprecated
    ISegmentDocumentDownloader getDownloaderByTenant(String discardTenantId, String fileId, String saveToPath);

    @Deprecated
    ISegmentDocumentDownloader getDownloaderByTenant(String discardTenantId, String bucketName, String fileId, String saveToPath);

    @Deprecated
    ISegmentDocumentDownloader getDownloaderByTenant(String discardTenantId, String bucketName, String fileId, String saveToPath, String driveToken);

    @Deprecated
    String deleteDocumentByTenant(String discardTenantId, String fileId);

    @Deprecated
    String deleteDocumentByTenant(String discardTenantId, String bucketName, String fileId);

    @Deprecated
    String deleteDocumentByTenant(String discardTenantId, String bucketName, String fileId, String driveToken);

    @Deprecated
    void deleteManyDocumentByTenant(String discardTenantId, BatchOperationIds operationIds);

    @Deprecated
    void deleteManyDocumentByTenant(String discardTenantId, String bucketName, BatchOperationIds operationIds);

    @Deprecated
    void deleteManyDocumentByTenant(String discardTenantId, String bucketName, BatchOperationIds operationIds, String driveToken);

    @Deprecated
    FileInfo getDocumentInfoByTenant(String discardTenantId, String fileId);

    @Deprecated
    FileInfo getDocumentInfoByTenant(String discardTenantId, String bucketName, String fileId);

    @Deprecated
    FileInfo getDocumentInfoByTenant(String discardTenantId, String bucketName, String fileId, String driveToken);

    @Deprecated
    void updateDocumentByTenant(String discardTenantId, String fileId, String fileName);

    @Deprecated
    void updateDocumentByTenant(String discardTenantId, String bucketName, String fileId, String fileName);

    @Deprecated
    void updateDocumentByTenant(String discardTenantId, String bucketName, String fileId, String fileName, String driveToken);

    @Deprecated
    void moveDocumentByTenant(String discardTenantId, String fileId, String targetDirectoryId);

    @Deprecated
    void moveDocumentByTenant(String discardTenantId, String bucketName, String fileId, String targetDirectoryId);

    @Deprecated
    void moveDocumentByTenant(String discardTenantId, String bucketName, String fileId, String targetDirectoryId, String driveToken);

    @Deprecated
    void moveManyDocumentByTenant(String discardTenantId, BatchOperationIds operationIds, String targetDirectoryId);

    @Deprecated
    void moveManyDocumentByTenant(String discardTenantId, String bucketName, BatchOperationIds operationIds, String targetDirectoryId);

    @Deprecated
    void moveManyDocumentByTenant(String discardTenantId, String bucketName, BatchOperationIds operationIds, String targetDirectoryId, String driveToken);

    @Deprecated
    String copyDocumentByTenant(String discardTenantId, String fileId, String targetDirectoryId);

    @Deprecated
    String copyDocumentByTenant(String discardTenantId, String bucketName, String fileId, String targetDirectoryId);

    @Deprecated
    String copyDocumentByTenant(String discardTenantId, String bucketName, String fileId, String targetDirectoryId, String driveToken);

    @Deprecated
    void copyManyDocumentByTenant(String discardTenantId, BatchOperationIds operationIds, String targetDirectoryId);

    @Deprecated
    void copyManyDocumentByTenant(String discardTenantId, String bucketName, BatchOperationIds operationIds, String targetDirectoryId);

    @Deprecated
    void copyManyDocumentByTenant(String discardTenantId, String bucketName, BatchOperationIds operationIds, String targetDirectoryId, String driveToken);

    @Deprecated
    String createDirectoryByTenant(String discardTenantId, String directoryName, String parentDirectoryId);

    @Deprecated
    String createDirectoryByTenant(String discardTenantId, String bucketName, String directoryName, String parentDirectoryId);

    @Deprecated
    String createDirectoryByTenant(String discardTenantId, String bucketName, String directoryName, String parentDirectoryId, String driveToken);

    @Deprecated
    DirInfo getDirectoryInfoByTenant(String discardTenantId, String directoryId);

    @Deprecated
    DirInfo getDirectoryInfoByTenant(String discardTenantId, String bucketName, String directoryId);

    @Deprecated
    DirInfo getDirectoryInfoByTenant(String discardTenantId, String bucketName, String directoryId, String driveToken);

    @Deprecated
    String deleteDirectoryByTenant(String discardTenantId, String directoryId);

    @Deprecated
    String deleteDirectoryByTenant(String discardTenantId, String bucketName, String directoryId);

    @Deprecated
    String deleteDirectoryByTenant(String discardTenantId, String bucketName, String directoryId, String driveToken);

    @Deprecated
    void updateDirectoryByTenant(String discardTenantId, String directoryId, String directoryName);

    @Deprecated
    void updateDirectoryByTenant(String discardTenantId, String bucketName, String directoryId, String directoryName);

    @Deprecated
    void updateDirectoryByTenant(String discardTenantId, String bucketName, String directoryId, String directoryName, String driveToken);

    @Deprecated
    void moveDirectoryByTenant(String discardTenantId, String directoryId, String targetDirectoryId);

    @Deprecated
    void moveDirectoryByTenant(String discardTenantId, String bucketName, String directoryId, String targetDirectoryId);

    @Deprecated
    void moveDirectoryByTenant(String discardTenantId, String bucketName, String directoryId, String targetDirectoryId, String driveToken);

    @Deprecated
    String copyDirectoryByTenant(String discardTenantId, String directoryId, String targetDirectoryId);

    @Deprecated
    String copyDirectoryByTenant(String discardTenantId, String bucketName, String directoryId, String targetDirectoryId);

    @Deprecated
    String copyDirectoryByTenant(String discardTenantId, String bucketName, String directoryId, String targetDirectoryId, String driveToken);

    @Deprecated
    ContentsResult listContentsByTenant(String discardTenantId, String directoryId);

    @Deprecated
    ContentsResult listContentsByTenant(String discardTenantId, String bucketName, String directoryId);

    @Deprecated
    ContentsResult listContentsByTenant(String discardTenantId, String bucketName, String directoryId, String driveToken);

    @Deprecated
    QueryResult queryFileInfoByFileInfoQueryByTenant(String discardTenantId, String bucketName, FileInfoQuery query, String driveToken);

    @Deprecated
    QueryResult queryFileInfoByFileInfoQueryByTenant(String discardTenantId, String bucketName, FileInfoQuery query);

    @Deprecated
    QueryResult queryFileInfoByFileInfoQueryByTenant(String discardTenantId, FileInfoQuery query);

    @Deprecated
    QueryResult queryFileInfoByFieldByTenant(String discardTenantId, String bucketName, String field, String value, String driveToken);

    @Deprecated
    QueryResult queryFileInfoByFieldByTenant(String discardTenantId, String bucketName, String field, String value);

    @Deprecated
    QueryResult queryFileInfoByFieldByTenant(String discardTenantId, String field, String value);

    @Deprecated
    QueryResult queryFileInfoByFieldWithPageByTenant(String discardTenantId, String bucketName, String field, String value, String pageNum, String pageSize, String driveToken);

    @Deprecated
    QueryResult queryFileInfoByFieldWithPageByTenant(String discardTenantId, String bucketName, String field, String value, String pageNum, String pageSize);

    @Deprecated
    QueryResult queryFileInfoByFieldWithPageByTenant(String discardTenantId, String field, String value, String pageNum, String pageSize);

    @Deprecated
    QueryResult queryFileInfoByOperatorWithPageByTenant(String discardTenantId, String bucketName, String field, String operator, String value, String pageNum, String pageSize, String driveToken);

    @Deprecated
    QueryResult queryFileInfoByOperatorWithPageByTenant(String discardTenantId, String bucketName, String field, String operator, String value, String pageNum, String pageSize);

    @Deprecated
    QueryResult queryFileInfoByOperatorWithPageByTenant(String discardTenantId, String field, String operator, String value, String pageNum, String pageSize);

    @Deprecated
    QueryResult queryFileInfoByOperatorByTenant(String discardTenantId, String bucketName, String field, String operator, String value, String driveToken);

    @Deprecated
    QueryResult queryFileInfoByOperatorByTenant(String discardTenantId, String bucketName, String field, String operator, String value);

    @Deprecated
    QueryResult queryFileInfoByOperatorByTenant(String discardTenantId, String field, String operator, String value);

    @Deprecated
    QueryResult queryFileInfoByFullTextByTenant(String discardTenantId, String bucketName, FullTextCondition search, String driveToken);

    @Deprecated
    QueryResult queryFileInfoByFullTextByTenant(String discardTenantId, String bucketName, FullTextCondition search);

    @Deprecated
    QueryResult queryFileInfoByFullTextByTenant(String discardTenantId, FullTextCondition search);

    /**
     * 获取普通文档上传器（默认存储区）
     *
     * @param discardTenantId 租户Id
     * @param localPath       上传文件路径
     * @param fileInfo        文件信息
     * @return 普通文档上传器
     */
    @Deprecated
    IGeneralDocumentUploader uploadDocumentByTenant(String discardTenantId, String localPath, FileInfo fileInfo);

    @Deprecated
    IGeneralDocumentUploader uploadDocumentByTenant(String discardTenantId, byte[] bytes, FileInfo fileInfo);
}

==> dmc-sdk-5.3.2.1-sources.jar: com/digiwin/dmc/sdk/service/discard/IDocumentStorageServiceDiscard.java <==
package com.digiwin.dmc.sdk.service.discard;

import com.digiwin.dap.middleware.dmc.common.context.TenantId;
import com.digiwin.dmc.sdk.entity.BatchOperationIds;
import com.digiwin.dmc.sdk.entity.ContentsResult;
import com.digiwin.dmc.sdk.entity.DirInfo;
import com.digiwin.dmc.sdk.entity.FileInfo;
import com.digiwin.dmc.sdk.entity.Query.FileInfoQuery;
import com.digiwin.dmc.sdk.entity.Query.FullTextCondition;
import com.digiwin.dmc.sdk.entity.Query.QueryResult;
import com.digiwin.dmc.sdk.service.download.IGeneralDocumentDownloader;
import com.digiwin.dmc.sdk.service.download.ISegmentDocumentDownloader;
import com.digiwin.dmc.sdk.service.upload.IGeneralDocumentUploader;
import com.digiwin.dmc.sdk.service.upload.ISegmentDocumentUploader;

/**
 * <ol>
 *      <li>以下API是旧版本Bucket租户拼接方案，此方案已经废弃，请不要使用.</li>
 *      <li>文件上传下载添加租户ID，可以通过如下方案：</li>
 *      <ol>
 *          <li>旧版API(即：com.digiwin.dmc)：通过方法参数{@link FileInfo#setTenantId(String)}或者通过方法参数{@link TenantId#of(String)}</li>
 *          <li>新版API(即：com.digiwin.dap.middleware)：{@link  com.digiwin.dap.middleware.dmc.DMC#setTenantId(String)}</li>
 *      </ol>
 *      <li>新版本使用范例：<a href="http://10.40.42.38/middleware/dapware-samples/tree/master/dapware-java/src/main/java/com/digiwin/dap/sdk/dmc">参考 </a></li>
 * <ol>
 *
 * @author fobgochod
 * @date 2022/6/8 13:31
 */
@Deprecated
public interface IDocumentStorageServiceDiscard {

    @Deprecated
    IGeneralDocumentUploader uploadDocumentByTenant(String discardTenantId, String bucketName, String localPath, FileInfo fileInfo);

    @Deprecated
    IGeneralDocumentUploader uploadDocumentByTenant(String discardTenantId, String bucketName, byte[] bytes, FileInfo fileInfo);

    @Deprecated
    IGeneralDocumentUploader uploadDocumentByTenant(String discardTenantId, String bucketName, String localPath, FileInfo fileInfo, String driveToken);

    @Deprecated
    IGeneralDocumentUploader uploadDocumentByTenant(String discardTenantId, String bucketName, byte[] bytes, FileInfo fileInfo, String driveToken);

    @Deprecated
    ISegmentDocumentUploader getUploaderByTenant(String discardTenantId, String localPath, FileInfo fileInfo);

    @Deprecated
    ISegmentDocumentUploader getUploaderByTenant(String discardTenantId, byte[] bytes, FileInfo fileInfo);

    @Deprecated
    ISegmentDocumentUploader getUploaderByTenant(String discardTenantId, String bucketName, String localPath, FileInfo fileInfo);

    @Deprecated
    ISegmentDocumentUploader getUploaderByTenant(String discardTenantId, String bucketName, byte[] bytes, FileInfo fileInfo);

    @Deprecated
    ISegmentDocumentUploader getUploaderByTenant(String discardTenantId, String bucketName, String localPath, FileInfo fileInfo, String driveToken);

    @Deprecated
    ISegmentDocumentUploader getUploaderByTenant(String discardTenantId, String bucketName, byte[] bytes, FileInfo fileInfo, String driveToken);

    @Deprecated
    IGeneralDocumentDownloader downloadDocumentByTenant(String discardTenantId, String fileId, String saveToPath);

    @Deprecated
    IGeneralDocumentDownloader downloadDocumentByTenant(String discardTenantId, String bucketName, String fileId, String saveToPath);

    @Deprecated
    IGeneralDocumentDownloader downloadDocumentByTenant(String discardTenantId, String bucketName, String fileId, String saveToPath, String driveToken);

    @Deprecated
    ISegmentDocumentDownloader getDownloaderByTenant(String discardTenantId, String fileId, String saveToPath);

    @Deprecated
    ISegmentDocumentDownloader getDownloaderByTenant(String discardTenantId, String bucketName, String fileId, String saveToPath);

    @Deprecated
    ISegmentDocumentDownloader getDownloaderByTenant(String discardTenantId, String bucketName, String fileId, String saveToPath, String driveToken);

    @Deprecated
    String deleteDocumentByTenant(String discardTenantId, String fileId);

    @Deprecated
    String deleteDocumentByTenant(String discardTenantId, String bucketName, String fileId);

    @Deprecated
    String deleteDocumentByTenant(String discardTenantId, String bucketName, String fileId, String driveToken);

    @Deprecated
    void deleteManyDocumentByTenant(String discardTenantId, BatchOperationIds operationIds);

    @Deprecated
    void deleteManyDocumentByTenant(String discardTenantId, String bucketName, BatchOperationIds operationIds);

    @Deprecated
    void deleteManyDocumentByTenant(String discardTenantId, String bucketName, BatchOperationIds operationIds, String driveToken);

    @Deprecated
    FileInfo getDocumentInfoByTenant(String discardTenantId, String fileId);

    @Deprecated
    FileInfo getDocumentInfoByTenant(String discardTenantId, String bucketName, String fileId);

    @Deprecated
    FileInfo getDocumentInfoByTenant(String discardTenantId, String bucketName, String fileId, String driveToken);

    @Deprecated
    void updateDocumentByTenant(String discardTenantId, String fileId, String fileName);

    @Deprecated
    void updateDocumentByTenant(String discardTenantId, String bucketName, String fileId, String fileName);

    @Deprecated
    void updateDocumentByTenant(String discardTenantId, String bucketName, String fileId, String fileName, String driveToken);

    @Deprecated
    void moveDocumentByTenant(String discardTenantId, String fileId, String targetDirectoryId);

    @Deprecated
    void moveDocumentByTenant(String discardTenantId, String bucketName, String fileId, String targetDirectoryId);

    @Deprecated
    void moveDocumentByTenant(String discardTenantId, String bucketName, String fileId, String targetDirectoryId, String driveToken);

    @Deprecated
    void moveManyDocumentByTenant(String discardTenantId, BatchOperationIds operationIds, String targetDirectoryId);

    @Deprecated
    void moveManyDocumentByTenant(String discardTenantId, String bucketName, BatchOperationIds operationIds, String targetDirectoryId);

    @Deprecated
    void moveManyDocumentByTenant(String discardTenantId, String bucketName, BatchOperationIds operationIds, String targetDirectoryId, String driveToken);

    @Deprecated
    String copyDocumentByTenant(String discardTenantId, String fileId, String targetDirectoryId);

    @Deprecated
    String copyDocumentByTenant(String discardTenantId, String bucketName, String fileId, String targetDirectoryId);

    @Deprecated
    String copyDocumentByTenant(String discardTenantId, String bucketName, String fileId, String targetDirectoryId, String driveToken);

    @Deprecated
    void copyManyDocumentByTenant(String discardTenantId, BatchOperationIds operationIds, String targetDirectoryId);

    @Deprecated
    void copyManyDocumentByTenant(String discardTenantId, String bucketName, BatchOperationIds operationIds, String targetDirectoryId);

    @Deprecated
    void copyManyDocumentByTenant(String discardTenantId, String bucketName, BatchOperationIds operationIds, String targetDirectoryId, String driveToken);

    @Deprecated
    String createDirectoryByTenant(String discardTenantId, String directoryName, String parentDirectoryId);

    @Deprecated
    String createDirectoryByTenant(String discardTenantId, String bucketName, String directoryName, String parentDirectoryId);

    @Deprecated
    String createDirectoryByTenant(String discardTenantId, String bucketName, String directoryName, String parentDirectoryId, String driveToken);

    @Deprecated
    DirInfo getDirectoryInfoByTenant(String discardTenantId, String directoryId);

    @Deprecated
    DirInfo getDirectoryInfoByTenant(String discardTenantId, String bucketName, String directoryId);

    @Deprecated
    DirInfo getDirectoryInfoByTenant(String discardTenantId, String bucketName, String directoryId, String driveToken);

    @Deprecated
    String deleteDirectoryByTenant(String discardTenantId, String directoryId);

    @Deprecated
    String deleteDirectoryByTenant(String discardTenantId, String bucketName, String directoryId);

    @Deprecated
    String deleteDirectoryByTenant(String discardTenantId, String bucketName, String directoryId, String driveToken);

    @Deprecated
    void updateDirectoryByTenant(String discardTenantId, String directoryId, String directoryName);

    @Deprecated
    void updateDirectoryByTenant(String discardTenantId, String bucketName, String directoryId, String directoryName);

    @Deprecated
    void updateDirectoryByTenant(String discardTenantId, String bucketName, String directoryId, String directoryName, String driveToken);

    @Deprecated
    void moveDirectoryByTenant(String discardTenantId, String directoryId, String targetDirectoryId);

    @Deprecated
    void moveDirectoryByTenant(String discardTenantId, String bucketName, String directoryId, String targetDirectoryId);

    @Deprecated
    void moveDirectoryByTenant(String discardTenantId, String bucketName, String directoryId, String targetDirectoryId, String driveToken);

    @Deprecated
    String copyDirectoryByTenant(String discardTenantId, String directoryId, String targetDirectoryId);

    @Deprecated
    String copyDirectoryByTenant(String discardTenantId, String bucketName, String directoryId, String targetDirectoryId);

    @Deprecated
    String copyDirectoryByTenant(String discardTenantId, String bucketName, String directoryId, String targetDirectoryId, String driveToken);

    @Deprecated
    ContentsResult listContentsByTenant(String discardTenantId, String directoryId);

    @Deprecated
    ContentsResult listContentsByTenant(String discardTenantId, String bucketName, String directoryId);

    @Deprecated
    ContentsResult listContentsByTenant(String discardTenantId, String bucketName, String directoryId, String driveToken);

    @Deprecated
    QueryResult queryFileInfoByFileInfoQueryByTenant(String discardTenantId, String bucketName, FileInfoQuery query, String driveToken);

    @Deprecated
    QueryResult queryFileInfoByFileInfoQueryByTenant(String discardTenantId, String bucketName, FileInfoQuery query);

    @Deprecated
    QueryResult queryFileInfoByFileInfoQueryByTenant(String discardTenantId, FileInfoQuery query);

    @Deprecated
    QueryResult queryFileInfoByFieldByTenant(String discardTenantId, String bucketName, String field, String value, String driveToken);

    @Deprecated
    QueryResult queryFileInfoByFieldByTenant(String discardTenantId, String bucketName, String field, String value);

    @Deprecated
    QueryResult queryFileInfoByFieldByTenant(String discardTenantId, String field, String value);

    @Deprecated
    QueryResult queryFileInfoByFieldWithPageByTenant(String discardTenantId, String bucketName, String field, String value, String pageNum, String pageSize, String driveToken);

    @Deprecated
    QueryResult queryFileInfoByFieldWithPageByTenant(String discardTenantId, String bucketName, String field, String value, String pageNum, String pageSize);

    @Deprecated
    QueryResult queryFileInfoByFieldWithPageByTenant(String discardTenantId, String field, String value, String pageNum, String pageSize);

    @Deprecated
    QueryResult queryFileInfoByOperatorWithPageByTenant(String discardTenantId, String bucketName, String field, String operator, String value, String pageNum, String pageSize, String driveToken);

    @Deprecated
    QueryResult queryFileInfoByOperatorWithPageByTenant(String discardTenantId, String bucketName, String field, String operator, String value, String pageNum, String pageSize);

    @Deprecated
    QueryResult queryFileInfoByOperatorWithPageByTenant(String discardTenantId, String field, String operator, String value, String pageNum, String pageSize);

    @Deprecated
    QueryResult queryFileInfoByOperatorByTenant(String discardTenantId, String bucketName, String field, String operator, String value, String driveToken);

    @Deprecated
    QueryResult queryFileInfoByOperatorByTenant(String discardTenantId, String bucketName, String field, String operator, String value);

    @Deprecated
    QueryResult queryFileInfoByOperatorByTenant(String discardTenantId, String field, String operator, String value);

    @Deprecated
    QueryResult queryFileInfoByFullTextByTenant(String discardTenantId, String bucketName, FullTextCondition search, String driveToken);

    @Deprecated
    QueryResult queryFileInfoByFullTextByTenant(String discardTenantId, String bucketName, FullTextCondition search);

    @Deprecated
    QueryResult queryFileInfoByFullTextByTenant(String discardTenantId, FullTextCondition search);

    /**
     * 获取普通文档上传器（默认存储区）
     *
     * @param discardTenantId 租户Id
     * @param localPath       上传文件路径
     * @param fileInfo        文件信息
     * @return 普通文档上传器
     */
    @Deprecated
    IGeneralDocumentUploader uploadDocumentByTenant(String discardTenantId, String localPath, FileInfo fileInfo);

    @Deprecated
    IGeneralDocumentUploader uploadDocumentByTenant(String discardTenantId, byte[] bytes, FileInfo fileInfo);
}
